==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qnx/blackberrydeviceconnectionmanager.h <==
/**************************************************************************
**
** Copyright (C) 2013 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H
#define QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H

#include <QObject>

#include <coreplugin/id.h>
#include <projectexplorer/devicesupport/idevice.h>

namespace Qnx {
namespace Internal {

class BlackBerryDeviceConnection;

class BlackBerryDeviceConnectionManager : public QObject
{
    Q_OBJECT
public:
    ~BlackBerryDeviceConnectionManager();

    void initialize();
    void killAllConnections();

    static BlackBerryDeviceConnectionManager *instance();

    bool isConnected(Core::Id deviceId);

    QString connectionLog(Core::Id deviceId) const;

    void connectDevice(const ProjectExplorer::IDevice::ConstPtr &device);
    void disconnectDevice(const ProjectExplorer::IDevice::ConstPtr &device);

    const QString privateKeyPath() const;
    bool hasValidSSHKeys() const;
    bool setSSHKeys(const QByteArray privateKeyContent, const QByteArray publicKeyContent,
            QString *error);

signals:
    void connectionOutput(Core::Id deviceId, const QString &output);
    void deviceAboutToConnect(Core::Id deviceId);
    void deviceConnected();
    void deviceDisconnected(Core::Id deviceId);

public slots:
    void connectDevice(Core::Id deviceId);
    void disconnectDevice(Core::Id deviceId);

private slots:
    void handleDeviceListChanged();

    void handleDeviceAboutToConnect();
    void handleDeviceConnected();
    void handleDeviceDisconnected();

    void handleProcessOutput(const QString &output);

    void processPendingDeviceConnections();

private:
    explicit BlackBerryDeviceConnectionManager();

    BlackBerryDeviceConnection *connectionForHost(const QString &host) const;
    QList<Core::Id> devicesForHost(const QString &host) const;

    int connectionUsageCount(Core::Id deviceId);

    void disconnectRemovedDevices();
    void reconnectChangedDevices();
    void connectAddedDevices();

    static BlackBerryDeviceConnectionManager *m_instance;
    QMultiMap<BlackBerryDeviceConnection*, Core::Id> m_connections;

    QList<ProjectExplorer::IDevice::ConstPtr> m_pendingDeviceConnections;
};

} // namespace Internal
} // namespace Qnx

#endif // QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H

==> qt-creator-opensource-src-3.2.0.zip: qt-creator-opensource-src-3.2.0/src/plugins/qnx/blackberrydeviceconnectionmanager.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H
#define QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H

#include <QObject>

#include <coreplugin/id.h>
#include <projectexplorer/devicesupport/idevice.h>

namespace Qnx {
namespace Internal {

class BlackBerryDeviceConnection;

class BlackBerryDeviceConnectionManager : public QObject
{
    Q_OBJECT
public:
    ~BlackBerryDeviceConnectionManager();

    void initialize();
    void killAllConnections();

    static BlackBerryDeviceConnectionManager *instance();

    bool isConnected(Core::Id deviceId);

    QString connectionLog(Core::Id deviceId) const;

    void connectDevice(const ProjectExplorer::IDevice::ConstPtr &device);
    void disconnectDevice(const ProjectExplorer::IDevice::ConstPtr &device);

    const QString privateKeyPath() const;
    bool hasValidSSHKeys() const;
    bool setSSHKeys(const QByteArray &privateKeyContent, const QByteArray &publicKeyContent,
            QString *error);

signals:
    void connectionOutput(Core::Id deviceId, const QString &output);
    void deviceAboutToConnect(Core::Id deviceId);
    void deviceConnected();
    void deviceDisconnected(Core::Id deviceId);

public slots:
    void connectDevice(Core::Id deviceId);
    void disconnectDevice(Core::Id deviceId);

private slots:
    void handleDeviceListChanged();

    void handleDeviceAboutToConnect();
    void handleDeviceConnected();
    void handleDeviceDisconnected();

    void handleProcessOutput(const QString &output);

    void processPendingDeviceConnections();

private:
    explicit BlackBerryDeviceConnectionManager();

    BlackBerryDeviceConnection *connectionForHost(const QString &host) const;
    QList<Core::Id> devicesForHost(const QString &host) const;

    int connectionUsageCount(Core::Id deviceId);

    void disconnectRemovedDevices();
    void reconnectChangedDevices();
    void connectAddedDevices();

    static BlackBerryDeviceConnectionManager *m_instance;
    QMultiMap<BlackBerryDeviceConnection*, Core::Id> m_connections;

    QList<ProjectExplorer::IDevice::ConstPtr> m_pendingDeviceConnections;
};

} // namespace Internal
} // namespace Qnx

#endif // QNX_INTERNAL_BLACKBERRYDEVICECONNECTIONMANAGER_H
